﻿// Animated lightning by Jim Bumgardner
//
curNbrBolts = 3;     // number of bolts
curColor = 0xFFFFFF; // color of lightning
curThick = 1;        // thickness of bolt
curDetail = 2;       // must not be zero, and probably no less than 1
curDisplace = 200;   // large values take longer to render

// Recursive function to draw a lightning bolt from x1,y1 to x2,y2
// using midpoint displacement
//
MovieClip.prototype.lightning = function(x1,y1,x2,y2,displace)
{
  if (displace < curDetail) {
		this.moveTo(x1,y1);
		this.lineTo(x2,y2);
	}
	else {
		var mid_x = (x2+x1)/2;
		var mid_y = (y2+y1)/2;
		mid_x += (Math.random()-.5)*displace;
		mid_y += (Math.random()-.5)*displace;
		this.lightning(x1,y1,mid_x,mid_y,displace/2);
		this.lightning(x2,y2,mid_x,mid_y,displace/2);
	}
}

this.onEnterFrame = function()
{
  // draw a set of lightning bolts..
  this.clear();
  this.lineStyle(curThick,0xFFFFFF);
  for (var i = 0; i < curNbrBolts; ++i)
	this.lightning(gen1_mc._x,gen1_mc._y,
				   gen2_mc._x,gen2_mc._y, 
				   curDisplace);
}

// Slider change functions - these are called when the knobs are fiddled with
//
function setNbrBolts(n)
{
	curNbrBolts = n;
}

function setThick(t)
{
	curThick = t;
}

function setDetail(d)
{
	curDetail = Math.max(1,d);
}

function setDisplace(n)
{
	curDisplace = n;
}

// Slider UI stuff - I usually prefer to roll my own sliders, rather than
// using components, since the code often ends up being nearly the
// same size, and I prefer having code I can see & understand.
// Nonetheless, I'm probably asking for trouble...
//

MovieClip.prototype.setupSlider = function(lab,min,max,val,changeFunc)
{
   this.minv = min;
   this.maxv = max;
   this.range = max - min;
   this.val = val;
   this.changeFunc = changeFunc;
   this.its_label.text = lab;
   this.its_value.text = val;
   this.knob_mc.useHandCursor = true;
   this.knob_mc._x = (this.val - this.minv)*200/this.range;
   this.changeFunc(this.val);
   this.onMouseMove = function() 
   {
	  if (!this.dragging)
		return;
	  x = this._xmouse;
	  if (x >= 0 && x <= 200) 
	  {
		  this.knob_mc._x = x;
		  var r = x/200;
		  this.val = this.minv + r*this.range;
		  this.its_value.text = Math.round(this.val);
		  this.changeFunc(this.val);
	  }
   };
   this.knob_mc._xscale = this.knob_mc._yscale = 90;
   this.knob_mc.onRollOver = function() { this._xscale = this._yscale = 100; };
   this.knob_mc.onRollOut = function() { this._xscale = this._yscale = 90; };
   this.knob_mc.onPress = function() { this._parent.dragging = true; };
   this.knob_mc.onRelease = function() { this._parent.dragging = false; };
   this.knob_mc.onReleaseOutside = function() { this._parent.dragging = false; };
}

// Setup the 4 sliders...
slider0_mc.setupSlider('detail',1,20, curDetail,setDetail);
slider1_mc.setupSlider('thickness',.1,10, curThick,setThick);
slider2_mc.setupSlider('number bolts',1,12, curNbrBolts,setNbrBolts);
slider3_mc.setupSlider('displacement',1,400, curDisplace,setDisplace);
